@@ -15,11 +15,9 @@ from .protocol.const import (  # noqa: F401
     SZ_ACTUATORS,
     SZ_AIR_QUALITY,
     SZ_AIR_QUALITY_BASE,
-    SZ_ALIAS,
     SZ_BOOST_TIMER,
     SZ_BYPASS_POSITION,
     SZ_CHANGE_COUNTER,
-    SZ_CLASS,
     SZ_CO2_LEVEL,
     SZ_DATETIME,
     SZ_DEVICE_ID,
@@ -32,6 +30,7 @@ from .protocol.const import (  # noqa: F401
     SZ_EXHAUST_FLOW,
     SZ_EXHAUST_TEMPERATURE,
     SZ_FAN_INFO,
+    SZ_FAN_MODE,
     SZ_FRAG_LENGTH,
     SZ_FRAG_NUMBER,
     SZ_FRAGMENT,
@@ -46,6 +45,7 @@ from .protocol.const import (  # noqa: F401
     SZ_PAYLOAD,
     SZ_POST_HEAT,
     SZ_PRE_HEAT,
+    SZ_PRESENCE_DETECTED,
     SZ_PRESSURE,
     SZ_PRIORITY,
     SZ_RELAY_DEMAND,
@@ -114,8 +114,6 @@ DONT_CREATE_MESSAGES = 3
 DONT_CREATE_ENTITIES = 2
 DONT_UPDATE_ENTITIES = 1
 
-SZ_FAKED = "faked"
-
 SCHED_REFRESH_INTERVAL = 3  # minutes
 
 # Status codes for Worcester Bosch boilers - OT|OEM diagnostic code
