@@ -758,10 +758,10 @@ class OtbGateway(Actuator, HeatDemand):  # OTB (10): 3220 (22D9, others)
                     Command.get_opentherm_data(self.id, m), 60 * 60, delay=90
                 )
 
-        for msg_id in STATUS_MSG_IDS:
+        for m in STATUS_MSG_IDS:
             if self._gwy.config.use_native_ot or m not in self.OT_TO_RAMSES:
                 self._add_discovery_task(
-                    Command.get_opentherm_data(self.id, msg_id), 60 * 5, delay=15
+                    Command.get_opentherm_data(self.id, m), 60 * 5, delay=15
                 )
 
         # TODO: both modulation level?
@@ -1023,7 +1023,7 @@ class OtbGateway(Actuator, HeatDemand):  # OTB (10): 3220 (22D9, others)
 
     @property
     def flame_active(self) -> None | bool:  # 3220|00, or 3EF0 (byte 3, only OTB)
-        if not self._gwy.config.use_native_ot:
+        if self._gwy.config.use_native_ot:
             return self._ot_msg_flag("00", 8 + 3)
         return self._msg_value(Code._3EF0, key=SZ_FLAME_ACTIVE)
 
