@@ -251,6 +251,10 @@ def set_pkt_logging(logger, dt_now=None, cc_console: bool = False, **kwargs) ->
     logger.propagate = False  # log file is distinct from any app/debug logging
     logger.setLevel(logging.DEBUG)  # must be at least .INFO
 
+    # as set_pkt_logging() may be called several times: to avoid duplicates in logs...
+    for handler in logger.handlers:  # dont use logger.hasHandlers() as not propagating
+        logger.removeHandler(handler)
+
     if file_name := kwargs.get(SZ_FILE_NAME):
         bkp_count = kwargs.get(SZ_ROTATE_BACKUPS, 0)
         max_bytes = kwargs.get(SZ_ROTATE_BYTES)
