@@ -424,7 +424,7 @@ def parser_000c(payload, msg) -> dict:
             seqx[:2] == payload[:2]
         ), f"idx != {payload[:2]} (seqx = {seqx}), short={is_short_000C(payload)}"
         assert int(seqx[:2], 16) < 16
-        assert seqx[4:6] == "7F" or seqx[6:] != "F" * 6
+        assert seqx[4:6] == "7F" or seqx[6:] != "F" * 6, f"Bad device_id: {seqx[6:]}"
         return {hex_id_to_dev_id(seqx[6:12]): seqx[4:6]}
 
     def is_short_000C(payload) -> bool:
@@ -1988,6 +1988,7 @@ def parser_313e(payload, msg) -> dict:
 def parser_313f(payload, msg) -> dict:  # TODO: look for TZ
     # 2020-03-28T03:59:21.315178 045 RP --- 01:158182 04:136513 --:------ 313F 009 00FC3500A41C0307E4  # noqa: E501
     # 2020-03-29T04:58:30.486343 045 RP --- 01:158182 04:136485 --:------ 313F 009 00FC8400C51D0307E4  # noqa: E501
+    # 2022-09-20T20:50:32.800676 065 RP --- 01:182924 18:068640 --:------ 313F 009 00F9203234140907E6
     # 2020-05-31T11:37:50.351511 056  I --- --:------ --:------ 12:207082 313F 009 0038021ECB1F0507E4  # noqa: E501
 
     # https://www.automatedhome.co.uk/vbulletin/showthread.php?5085-My-HGI80-equivalent-Domoticz-setup-without-HGI80&p=36422&viewfull=1#post36422
@@ -1995,6 +1996,7 @@ def parser_313f(payload, msg) -> dict:  # TODO: look for TZ
 
     assert msg.src.type != DEV_TYPE_MAP.CTL or payload[2:4] in (
         "F0",
+        "F9",
         "FC",
     ), f"{payload[2:4]} unexpected for CTL"  # DEX
     assert (
