@@ -164,11 +164,15 @@ class SystemBase(Parent, Entity):  # 3B00 (multi-relay)
     def _setup_discovery_tasks(self) -> None:
         # super()._setup_discovery_tasks()
 
-        self._add_discovery_task(
-            _mk_cmd(RQ, Code._000C, f"00{DEV_ROLE_MAP.HTG}", self.id),
-            60 * 60 * 24,
-            delay=0,
-        )
+        for payload in (
+            f"00{DEV_ROLE_MAP.APP}",  # appliance_control
+            f"00{DEV_ROLE_MAP.HTG}",  # hotwater_valve
+            f"01{DEV_ROLE_MAP.HTG}",  # heating_valve
+        ):
+            self._add_discovery_task(
+                _mk_cmd(RQ, Code._000C, payload, self.ctl.id), 60 * 60 * 24, delay=0
+            )
+
         self._add_discovery_task(Command.get_tpi_params(self.id), 60 * 60 * 6, delay=5)
 
     def _handle_msg(self, msg: Message) -> None:
@@ -618,7 +622,7 @@ class MultiZone(SystemBase):  # 0005 (+/- 000C?)
         ):
             return
 
-        # TODO: a I/0005 may have changed zones & may need a restart (del) or not (add)
+        # TODO: a I/0005 may have changed: del or add zones
         if msg.code == Code._0005:
             if (zone_type := msg.payload[SZ_ZONE_TYPE]) in ZON_ROLE_MAP.HEAT_ZONES:
                 [
@@ -636,16 +640,22 @@ class MultiZone(SystemBase):  # 0005 (+/- 000C?)
                 ]
             return
 
-        if (
-            msg.code == Code._000C
-            and msg.payload[SZ_ZONE_TYPE] in DEV_ROLE_MAP.HEAT_DEVICES
-        ):
+        # TODO: a I/000C may have changed: del or add devices
+        if msg.code == Code._000C:
+            if msg.payload[SZ_ZONE_TYPE] not in DEV_ROLE_MAP.HEAT_DEVICES:
+                return
             if msg.payload[SZ_DEVICES]:
                 self.get_htg_zone(msg.payload[SZ_ZONE_IDX], msg=msg)
             elif zon := self.zone_by_idx.get(msg.payload[SZ_ZONE_IDX]):
                 zon._handle_msg(msg)  # tell existing zone: no device
             return
 
+        # the CTL knows, but does not announce temps for multiroom_mode zones
+        if msg.code == Code._30C9 and msg._has_array:
+            for z in self.zones:
+                if z.idx not in (x[SZ_ZONE_IDX] for x in msg.payload):
+                    z._get_temp()
+
         # If some zones still don't have a sensor, maybe eavesdrop?
         if self._gwy.config.enable_eavesdrop and (
             msg.code in (Code._000A, Code._2309, Code._30C9) and msg._has_array
@@ -809,10 +819,14 @@ class ScheduleSync(SystemBase):  # 0006 (+/- 0404?)
         self.zone_lock.release()
 
     @property
-    def params(self) -> dict[str, Any]:
+    def schedule_version(self) -> None | int:
+        return self._msg_value(Code._0006, key=SZ_CHANGE_COUNTER)
+
+    @property
+    def status(self) -> dict[str, Any]:
         return {
-            **super().params,
-            SZ_CHANGE_COUNTER: self._msg_value(Code._0006, key=SZ_CHANGE_COUNTER),
+            **super().status,
+            "schedule_version": self.schedule_version,
         }
 
 
@@ -947,11 +961,14 @@ class StoredHw(SystemBase):  # 10A0, 1260, 1F41
     def _setup_discovery_tasks(self) -> None:
         super()._setup_discovery_tasks()
 
-        self._add_discovery_task(
-            _mk_cmd(RQ, Code._000C, f"00{DEV_ROLE_MAP.DHW}", self.id),
-            60 * 60 * 24,
-            delay=0,
-        )
+        for payload in (
+            f"00{DEV_ROLE_MAP.DHW}",  # dhw_sensor
+            # f"00{DEV_ROLE_MAP.HTG}",  # hotwater_valve
+            # f"01{DEV_ROLE_MAP.HTG}",  # heating_valve
+        ):
+            self._add_discovery_task(
+                _mk_cmd(RQ, Code._000C, payload, self.id), 60 * 60 * 24, delay=0
+            )
 
     def _handle_msg(self, msg: Message) -> None:
 
