@@ -20,7 +20,6 @@ from ..const import (
     SZ_NAME,
     SZ_RELAY_DEMAND,
     SZ_RELAY_FAILSAFE,
-    SZ_SCHEDULE,
     SZ_SETPOINT,
     SZ_TEMPERATURE,
     SZ_WINDOW_OPEN,
@@ -168,16 +167,19 @@ class ZoneSchedule:  # 0404
 
     @property
     def schedule(self) -> None | dict:
-        """Return the latest known schedule (not guaranteed to be up to date)."""
-        if self._schedule._schedule:
-            return self._schedule._schedule[SZ_SCHEDULE]
-        return None
+        """Return the latest retreived schedule (not guaranteed to be up to date)."""
+        return self._schedule.schedule
+
+    @property
+    def schedule_version(self) -> None | int:
+        """Return the version number associated with the latest retrieved schedule."""
+        return self._schedule.version
 
     @property
     def status(self) -> dict[str, Any]:
         return {
             **super().status,
-            SZ_SCHEDULE: self.schedule,
+            "schedule_version": self.schedule_version,
         }
 
 
@@ -609,7 +611,9 @@ class Zone(ZoneSchedule, ZoneBase):
 
         super()._handle_msg(msg)
 
-        if msg.code == Code._000C and msg.payload[SZ_DEVICES]:
+        if msg.code == Code._000C:
+            if not msg.payload[SZ_DEVICES]:
+                return
 
             if msg.payload[SZ_ZONE_TYPE] == DEV_ROLE_MAP.SEN:
                 dev_id = msg.payload[SZ_DEVICES][0]
@@ -641,7 +645,7 @@ class Zone(ZoneSchedule, ZoneBase):
         return super()._msg_value(*args, **kwargs, zone_idx=self.idx)
 
     @property
-    def sensor(self) -> Device:
+    def sensor(self) -> None | Device:
         return self._sensor
 
     @property
@@ -660,11 +664,11 @@ class Zone(ZoneSchedule, ZoneBase):
         self._send_cmd(Command.set_zone_name(self.ctl.id, self.idx, value))
 
     @property
-    def config(self) -> Optional[dict]:  # 000A
+    def config(self) -> None | dict:  # 000A
         return self._msg_value(Code._000A)
 
     @property
-    def mode(self) -> Optional[dict]:  # 2349
+    def mode(self) -> None | dict:  # 2349
         return self._msg_value(Code._2349)
 
     @property
@@ -698,7 +702,7 @@ class Zone(ZoneSchedule, ZoneBase):
         """Return an estimate of the zone's current window_open state."""
         return self._msg_value(Code._12B0, key=SZ_WINDOW_OPEN)
 
-    def _get_temp(self) -> Future:  # TODO: messy - needs tidy up
+    def _get_temp(self) -> Future:
         """Get the zone's latest temp from the Controller."""
         return self._send_cmd(Command.get_zone_temp(self.ctl.id, self.idx))
 
